@@ -72,19 +72,24 @@ def add_row_to_delivered_path(row, chunk_number, job_uuid, file_headers, timesta
     delivered_path_pattern = os.path.join(get_settings().get('upload_folder', '/apps/files/'),
                                           'delivered-{job_uuid}-{chunk_number}.csv')
     delivered_path = delivered_path_pattern.format(chunk_number=chunk_number, job_uuid=job_uuid)
-    if row:
-        for segment_uuid, operation in {k: row[idx] for idx, k in enumerate(file_headers) if
-                                        k not in ['internal_user_id', 'external_user_id', 'id_type', 'policy_uuid'] and row[
-                                            idx] != ''}.items():
-            delivered_path, pointer, writer = add_to_file(
-                path=delivered_path, row=[
-                    segment_uuid,
-                    row[file_headers.index('internal_user_id')], row[file_headers.index('external_user_id')],
-                    row[file_headers.index('id_type')], operation, job_uuid,
-                    row[file_headers.index('policy_uuid')], timestamp], headers=delivered_headers, delimiter=',',
-                pointer=pointer,
-                writer=writer,
-            )
+    for segment_uuid, operation in {k: row[idx] for idx, k in enumerate(file_headers) if
+                                    k not in ['internal_user_id', 'external_user_id', 'id_type', 'policy_uuid',
+                                              'created_ts'] and row[
+                                        idx] != ''}.items():
+        delivered_path, pointer, writer = add_to_file(
+            path=delivered_path, row=[
+                segment_uuid,
+                row[file_headers.index('internal_user_id')],
+                row[file_headers.index('external_user_id')],
+                row[file_headers.index('id_type')],
+                operation,
+                job_uuid,
+                row[file_headers.index('policy_uuid')],
+                timestamp
+            ], headers=delivered_headers, delimiter=',',
+            pointer=pointer,
+            writer=writer,
+        )
     return delivered_path, pointer, writer
 
 
